thorn.environment.django — Thorn 1.3.0 documentation

# thorn.environment.django

- thorn.environment.django

## thorn.environment.django

Django web framework environment.

class `thorn.environment.django.` `DjangoEnv`
  `Subscriber`
  `Subscribers`
  static `autodetect`(env=u'DJANGO_SETTINGS_MODULE')
  `config`
  `reverse`
  `reverse_cls` = u'django.core.urlresolvers:reverse'
  `settings_cls` = u'django.conf:settings'
  `signals`
  `signals_cls` = u'thorn.django.signals'
  `subscriber_cls` = u'thorn.django.models:Subscriber'